@@ -10,7 +10,12 @@ from nowcasting_dataset.consts import (
 )
 from pydantic import Field, validator
 
-from nowcasting_dataloader.data_sources.datasource_output import Array, DataSourceOutputML
+from nowcasting_dataloader.data_sources.datasource_output import (
+    OSGB_X_MAX,
+    OSGB_Y_MAX,
+    Array,
+    DataSourceOutputML,
+)
 
 logger = logging.getLogger(__name__)
 
@@ -75,15 +80,37 @@ class GSPML(DataSourceOutputML):
         return v
 
     @validator("gsp_x_coords")
-    def x_coordinates_shape(cls, v, values):
+    def x_coordinates(cls, v, values):
         """Validate 'gsp_x_coords'"""
         assert v.shape[-1] == values["gsp_yield"].shape[-1]
+        if values["normalized"]:
+            if v.max() > 1:
+                raise Exception(
+                    f"GSP data is normalized, "
+                    f"but GSP X coordinates maximum value is above 1, {v.max()}"
+                )
+            if v.min() < 0:
+                raise Exception(
+                    f"GSP data is normalized, "
+                    f"but GSP X coordinates minimum value is below 0, {v.min()}"
+                )
         return v
 
     @validator("gsp_y_coords")
     def y_coordinates_shape(cls, v, values):
         """Validate 'gsp_y_coords'"""
         assert v.shape[-1] == values["gsp_yield"].shape[-1]
+        if values["normalized"]:
+            if v.max() > 1:
+                raise Exception(
+                    f"GSP data is normalized, "
+                    f"but GSP Y coordinates maximum value is above 1, {v.max()}"
+                )
+            if v.min() < 0:
+                raise Exception(
+                    f"GSP data is normalized, "
+                    f"but GSP Y coordinates minimum value is below 0, {v.min()}"
+                )
         return v
 
     def get_datetime_index(self) -> Array:
@@ -112,4 +139,8 @@ class GSPML(DataSourceOutputML):
         """Normalize the gsp data"""
         if not self.normalized:
             self.gsp_yield = self.gsp_yield / self.gsp_capacity
+
+            self.gsp_x_coords = self.gsp_x_coords / OSGB_X_MAX
+            self.gsp_y_coords = self.gsp_y_coords / OSGB_Y_MAX
+
             self.normalized = True
